@@ -64,7 +64,8 @@ INSERT INTO equipment_r (name, hobby)
     VALUES ('guts', 'skywalking');
 
 INSERT INTO city
-    VALUES ('Podunk', '(1,2),(3,4)', '100,127,1000'), ('Gotham', '(1000,34),(1100,334)', '123456,127,-1000,6789');
+    VALUES ('Podunk', '(1,2),(3,4)', '100,127,1000'),
+    ('Gotham', '(1000,34),(1100,334)', '123456,127,-1000,6789');
 
 TABLE city;
 
