@@ -290,7 +290,8 @@ CREATE TABLE undroppable_objs (
 );
 
 INSERT INTO undroppable_objs
-    VALUES ('table', 'schema_one.table_three'), ('table', 'audit_tbls.schema_two_table_three');
+    VALUES ('table', 'schema_one.table_three'),
+    ('table', 'audit_tbls.schema_two_table_three');
 
 CREATE TABLE dropped_objects (
     type text,
@@ -420,13 +421,14 @@ $$;
 CREATE EVENT TRIGGER regress_event_trigger_report_dropped ON sql_drop
     EXECUTE PROCEDURE event_trigger_report_dropped ();
 
-CREATE SCHEMA evttrig CREATE TABLE one (
-    col_a serial PRIMARY KEY,
-    col_b text DEFAULT 'forty two')
-CREATE INDEX one_idx ON one (
-    col_b)
-CREATE TABLE two (
-    col_c integer CHECK (col_c > 0) REFERENCES one DEFAULT 42
+CREATE SCHEMA evttrig
+    CREATE TABLE one (
+        col_a serial PRIMARY KEY,
+        col_b text DEFAULT 'forty two')
+    CREATE INDEX one_idx ON one (
+        col_b)
+    CREATE TABLE two (
+        col_c integer CHECK (col_c > 0) REFERENCES one DEFAULT 42
 );
 
 -- Partitioned tables with a partitioned index
