@@ -120,7 +120,7 @@ INSERT INTO T
     (4);
 
 ALTER TABLE T
-    ADD COLUMN c_text TEXT DEFAULT 'world',
+    ADD COLUMN c_text text DEFAULT 'world',
     ALTER COLUMN c_bpchar SET DEFAULT 'dog';
 
 INSERT INTO T
@@ -128,7 +128,7 @@ INSERT INTO T
     (6);
 
 ALTER TABLE T
-    ADD COLUMN c_date DATE DEFAULT '2016-06-02',
+    ADD COLUMN c_date date DEFAULT '2016-06-02',
     ALTER COLUMN c_text SET DEFAULT 'cat';
 
 INSERT INTO T
@@ -136,8 +136,8 @@ INSERT INTO T
     (8);
 
 ALTER TABLE T
-    ADD COLUMN c_timestamp TIMESTAMP DEFAULT '2016-09-01 12:00:00',
-    ADD COLUMN c_timestamp_null TIMESTAMP,
+    ADD COLUMN c_timestamp timestamp DEFAULT '2016-09-01 12:00:00',
+    ADD COLUMN c_timestamp_null timestamp,
     ALTER COLUMN c_date SET DEFAULT '2010-01-01';
 
 INSERT INTO T
@@ -145,7 +145,7 @@ INSERT INTO T
     (10);
 
 ALTER TABLE T
-    ADD COLUMN c_array TEXT[] DEFAULT '{"This", "is", "the", "real", "world"}',
+    ADD COLUMN c_array text[] DEFAULT '{"This", "is", "the", "real", "world"}',
     ALTER COLUMN c_timestamp SET DEFAULT '1970-12-31 11:12:13',
     ALTER COLUMN c_timestamp_null SET DEFAULT '2016-09-29 12:00:00';
 
@@ -154,8 +154,8 @@ INSERT INTO T
     (12);
 
 ALTER TABLE T
-    ADD COLUMN c_small SMALLINT DEFAULT -5,
-    ADD COLUMN c_small_null SMALLINT,
+    ADD COLUMN c_small smallint DEFAULT -5,
+    ADD COLUMN c_small_null smallint,
     ALTER COLUMN c_array SET DEFAULT '{"This", "is", "no", "fantasy"}';
 
 INSERT INTO T
@@ -163,7 +163,7 @@ INSERT INTO T
     (14);
 
 ALTER TABLE T
-    ADD COLUMN c_big BIGINT DEFAULT 180000000000018,
+    ADD COLUMN c_big bigint DEFAULT 180000000000018,
     ALTER COLUMN c_small SET DEFAULT 9,
     ALTER COLUMN c_small_null SET DEFAULT 13;
 
@@ -172,7 +172,7 @@ INSERT INTO T
     (16);
 
 ALTER TABLE T
-    ADD COLUMN c_num NUMERIC DEFAULT 1.00000000001,
+    ADD COLUMN c_num numeric DEFAULT 1.00000000001,
     ALTER COLUMN c_big SET DEFAULT -9999999999999999;
 
 INSERT INTO T
@@ -180,7 +180,7 @@ INSERT INTO T
     (18);
 
 ALTER TABLE T
-    ADD COLUMN c_time TIME DEFAULT '12:00:00',
+    ADD COLUMN c_time time DEFAULT '12:00:00',
     ALTER COLUMN c_num SET DEFAULT 2.000000000000002;
 
 INSERT INTO T
@@ -188,7 +188,7 @@ INSERT INTO T
     (20);
 
 ALTER TABLE T
-    ADD COLUMN c_interval INTERVAL DEFAULT '1 day',
+    ADD COLUMN c_interval interval DEFAULT '1 day',
     ALTER COLUMN c_time SET DEFAULT '23:59:59';
 
 INSERT INTO T
@@ -196,7 +196,7 @@ INSERT INTO T
     (22);
 
 ALTER TABLE T
-    ADD COLUMN c_hugetext TEXT DEFAULT repeat('abcdefg', 1000),
+    ADD COLUMN c_hugetext text DEFAULT repeat('abcdefg', 1000),
     ALTER COLUMN c_interval SET DEFAULT '3 hours';
 
 INSERT INTO T
@@ -295,7 +295,7 @@ INSERT INTO T
     (4);
 
 ALTER TABLE T
-    ADD COLUMN c_text TEXT DEFAULT foo (6),
+    ADD COLUMN c_text text DEFAULT foo (6),
     ALTER COLUMN c_bpchar SET DEFAULT foo (3);
 
 INSERT INTO T
@@ -303,7 +303,7 @@ INSERT INTO T
     (6);
 
 ALTER TABLE T
-    ADD COLUMN c_date DATE DEFAULT '2016-06-02'::date + LENGTH(foo (10)),
+    ADD COLUMN c_date date DEFAULT '2016-06-02'::date + LENGTH(foo (10)),
     ALTER COLUMN c_text SET DEFAULT foo (12);
 
 INSERT INTO T
@@ -311,7 +311,7 @@ INSERT INTO T
     (8);
 
 ALTER TABLE T
-    ADD COLUMN c_timestamp TIMESTAMP DEFAULT '2016-09-01'::date + LENGTH(foo (10)),
+    ADD COLUMN c_timestamp timestamp DEFAULT '2016-09-01'::date + LENGTH(foo (10)),
     ALTER COLUMN c_date SET DEFAULT '2010-01-01'::date - LENGTH(foo (4));
 
 INSERT INTO T
@@ -319,7 +319,7 @@ INSERT INTO T
     (10);
 
 ALTER TABLE T
-    ADD COLUMN c_array TEXT[] DEFAULT ('{"This", "is", "' || foo (4) || '","the", "real", "world"}')::text[],
+    ADD COLUMN c_array text[] DEFAULT ('{"This", "is", "' || foo (4) || '","the", "real", "world"}')::text[],
     ALTER COLUMN c_timestamp SET DEFAULT '1970-12-31'::date + LENGTH(foo (30));
 
 INSERT INTO T
@@ -370,14 +370,14 @@ SELECT
 
 -- now() is stable, because it returns the transaction timestamp
 ALTER TABLE T
-    ADD COLUMN c1 TIMESTAMP DEFAULT now();
+    ADD COLUMN c1 timestamp DEFAULT now();
 
 SELECT
     comp ();
 
 -- clock_timestamp() is volatile
 ALTER TABLE T
-    ADD COLUMN c2 TIMESTAMP DEFAULT clock_timestamp();
+    ADD COLUMN c2 timestamp DEFAULT clock_timestamp();
 
 SELECT
     comp ();
@@ -399,7 +399,7 @@ FROM
     generate_series(1, 10) a;
 
 ALTER TABLE T
-    ADD COLUMN c_bigint BIGINT NOT NULL DEFAULT -1;
+    ADD COLUMN c_bigint bigint NOT NULL DEFAULT -1;
 
 INSERT INTO T
 SELECT
@@ -409,7 +409,7 @@ FROM
     generate_series(11, 20) a (b);
 
 ALTER TABLE T
-    ADD COLUMN c_text TEXT DEFAULT 'hello';
+    ADD COLUMN c_text text DEFAULT 'hello';
 
 INSERT INTO T
 SELECT
@@ -425,7 +425,7 @@ SELECT
 FROM
     T
 WHERE
-    c_bigint = - 1
+    c_bigint = -1
 LIMIT 1;
 
 EXPLAIN (
@@ -438,7 +438,7 @@ SELECT
 FROM
     T
 WHERE
-    c_bigint = - 1
+    c_bigint = -1
 LIMIT 1;
 
 SELECT
@@ -584,14 +584,14 @@ INSERT INTO T
     (2);
 
 ALTER TABLE T
-    ADD COLUMN c_int INT NOT NULL DEFAULT -1;
+    ADD COLUMN c_int int NOT NULL DEFAULT -1;
 
 INSERT INTO T
     VALUES (3),
     (4);
 
 ALTER TABLE T
-    ADD COLUMN c_text TEXT DEFAULT 'Hello';
+    ADD COLUMN c_text text DEFAULT 'Hello';
 
 INSERT INTO T
     VALUES (5),
@@ -620,7 +620,7 @@ SELECT
 FROM
     T
 WHERE
-    c_int = - 1;
+    c_int = -1;
 
 SELECT
     comp ();
@@ -1009,10 +1009,10 @@ INSERT INTO vtype
     VALUES (1);
 
 ALTER TABLE vtype
-    ADD COLUMN b DOUBLE PRECISION DEFAULT 0.2;
+    ADD COLUMN b double precision DEFAULT 0.2;
 
 ALTER TABLE vtype
-    ADD COLUMN c BOOLEAN DEFAULT TRUE;
+    ADD COLUMN c boolean DEFAULT TRUE;
 
 SELECT
     *
