@@ -63,7 +63,14 @@ CREATE temp TABLE gstest4 (
 );
 
 INSERT INTO gstest4
-    VALUES (1, 1, b'0000', '1'), (2, 2, b'0001', '1'), (3, 4, b'0010', '2'), (4, 8, b'0011', '2'), (5, 16, b'0000', '2'), (6, 32, b'0001', '2'), (7, 64, b'0010', '1'), (8, 128, b'0011', '1');
+    VALUES (1, 1, b'0000', '1'),
+    (2, 2, b'0001', '1'),
+    (3, 4, b'0010', '2'),
+    (4, 8, b'0011', '2'),
+    (5, 16, b'0000', '2'),
+    (6, 32, b'0001', '2'),
+    (7, 64, b'0010', '1'),
+    (8, 128, b'0011', '1');
 
 CREATE temp TABLE gstest_empty (
     a integer,
@@ -216,8 +223,8 @@ FROM
 GROUP BY
     GROUPING SETS ((),
     GROUPING SETS ((),
-    GROUPING SETS (((a,
-                b)))))
+    GROUPING SETS (a,
+                b)))
 ORDER BY
     1 DESC;
 
@@ -256,8 +263,8 @@ SELECT
 FROM
     gstest2
 GROUP BY
-    GROUPING SETS (GROUPING SETS ((a,
-                b)))
+    GROUPING SETS (GROUPING SETS (a,
+                b))
 ORDER BY
     1 DESC;
 
@@ -280,7 +287,7 @@ GROUP BY
     GROUPING SETS (GROUPING SETS (a,
             GROUPING SETS (a,
                 GROUPING SETS (a),
-                ((a)),
+                (a),
                 a,
                 GROUPING SETS (a),
                 (a)),
