@@ -1304,7 +1304,9 @@ CREATE temp TABLE tt4 (
 );
 
 INSERT INTO tt4
-    VALUES (0), (1), (9999);
+    VALUES (0),
+    (1),
+    (9999);
 
 ANALYZE tt4;
 
@@ -2912,13 +2914,18 @@ CREATE TEMP TABLE d (
     b int
 );
 INSERT INTO a
-    VALUES (0, 0), (1, NULL);
+    VALUES (0, 0),
+    (1, NULL);
 INSERT INTO b
-    VALUES (0, 0), (1, NULL);
+    VALUES (0, 0),
+    (1, NULL);
 INSERT INTO c
-    VALUES (0), (1);
+    VALUES (0),
+    (1);
 INSERT INTO d
-    VALUES (1, 3), (2, 2), (3, 1);
+    VALUES (1, 3),
+    (2, 2),
+    (3, 1);
 -- all three cases should be optimizable into a simple seqscan
 EXPLAIN (
     COSTS OFF
@@ -3084,10 +3091,13 @@ CREATE temp TABLE child (
 );
 
 INSERT INTO parent
-    VALUES (1, 10), (2, 20), (3, 30);
+    VALUES (1, 10),
+    (2, 20),
+    (3, 30);
 
 INSERT INTO child
-    VALUES (1, 100), (4, 400);
+    VALUES (1, 100),
+    (4, 400);
 
 -- this case is optimizable
 SELECT
@@ -3186,9 +3196,11 @@ CREATE TEMP TABLE b (
     a_id int
 );
 INSERT INTO a
-    VALUES (0), (1);
+    VALUES (0),
+    (1);
 INSERT INTO b
-    VALUES (0, 0), (1, NULL);
+    VALUES (0, 0),
+    (1, NULL);
 SELECT
     *
 FROM
@@ -4448,7 +4460,8 @@ CREATE TABLE join_pt1p1p1 PARTITION OF join_pt1p1
 FOR VALUES FROM (0) TO (100);
 
 INSERT INTO join_pt1
-    VALUES (1, 1, 'x'), (101, 101, 'y');
+    VALUES (1, 1, 'x'),
+    (101, 101, 'y');
 
 CREATE TABLE join_ut1 (
     a int,
@@ -4457,7 +4470,8 @@ CREATE TABLE join_ut1 (
 );
 
 INSERT INTO join_ut1
-    VALUES (101, 101, 'y'), (2, 2, 'z');
+    VALUES (101, 101, 'y'),
+    (2, 2, 'z');
 
 EXPLAIN (
     VERBOSE,
@@ -4564,13 +4578,18 @@ CREATE TABLE j3 (
 );
 
 INSERT INTO j1
-    VALUES (1), (2), (3);
+    VALUES (1),
+    (2),
+    (3);
 
 INSERT INTO j2
-    VALUES (1), (2), (3);
+    VALUES (1),
+    (2),
+    (3);
 
 INSERT INTO j3
-    VALUES (1), (1);
+    VALUES (1),
+    (1);
 
 ANALYZE j1;
 
@@ -4723,7 +4742,8 @@ CREATE TABLE j3 (
 );
 
 INSERT INTO j1
-    VALUES (1, 1), (1, 2);
+    VALUES (1, 1),
+    (1, 2);
 
 INSERT INTO j2
     VALUES (1, 1);
