@@ -1335,14 +1335,15 @@ CREATE TYPE jsbrec AS (
     ia2d jsb_int_array_2d,
     t text,
     ta text[],
-    c char ( 10),
+    c char(10),
     ca char(10)[],
     ts timestamp,
     js json,
     jsb jsonb,
     jsa json[],
     rec jbpop,
-    reca jbpop[]);
+    reca jbpop[]
+);
 
 CREATE TYPE jsbrec_i_not_null AS (
     i jsb_int_not_null
@@ -2126,56 +2127,56 @@ SELECT
 FROM
     testjsonb
 WHERE
-    j @ ? '$.wait ? (@ == null)';
+    j @? '$.wait ? (@ == null)';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$.wait ? ("CC" == @)';
+    j @? '$.wait ? ("CC" == @)';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$ ? (@.wait == "CC" && true == @.public)';
+    j @? '$ ? (@.wait == "CC" && true == @.public)';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$.age ? (@ == 25)';
+    j @? '$.age ? (@ == 25)';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$ ? (@.age == 25.0)';
+    j @? '$ ? (@.age == 25.0)';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$';
+    j @? '$';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$.public';
+    j @? '$.public';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$.bar';
+    j @? '$.bar';
 
 CREATE INDEX jidx ON testjsonb USING gin (j);
 
@@ -2403,84 +2404,84 @@ SELECT
 FROM
     testjsonb
 WHERE
-    j @ ? '$.wait ? (@ == null)';
+    j @? '$.wait ? (@ == null)';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$.wait ? (@ == null)';
+    j @? '$.wait ? (@ == null)';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$.wait ? ("CC" == @)';
+    j @? '$.wait ? ("CC" == @)';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$ ? (@.wait == "CC" && true == @.public)';
+    j @? '$ ? (@.wait == "CC" && true == @.public)';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$.age ? (@ == 25)';
+    j @? '$.age ? (@ == 25)';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$ ? (@.age == 25.0)';
+    j @? '$ ? (@.age == 25.0)';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$ ? (@.array[*] == "bar")';
+    j @? '$ ? (@.array[*] == "bar")';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$.array ? (@[*] == "bar")';
+    j @? '$.array ? (@[*] == "bar")';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$.array[*] ? (@ == "bar")';
+    j @? '$.array[*] ? (@ == "bar")';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$';
+    j @? '$';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$.public';
+    j @? '$.public';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$.bar';
+    j @? '$.bar';
 
 -- array exists - array elements should behave as keys (for GIN index scans too)
 CREATE INDEX jidx_array ON testjsonb USING gin ((j -> 'array'));
@@ -2765,84 +2766,84 @@ SELECT
 FROM
     testjsonb
 WHERE
-    j @ ? '$.wait ? (@ == null)';
+    j @? '$.wait ? (@ == null)';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$.wait ? (@ == null)';
+    j @? '$.wait ? (@ == null)';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$.wait ? ("CC" == @)';
+    j @? '$.wait ? ("CC" == @)';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$ ? (@.wait == "CC" && true == @.public)';
+    j @? '$ ? (@.wait == "CC" && true == @.public)';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$.age ? (@ == 25)';
+    j @? '$.age ? (@ == 25)';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$ ? (@.age == 25.0)';
+    j @? '$ ? (@.age == 25.0)';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$ ? (@.array[*] == "bar")';
+    j @? '$ ? (@.array[*] == "bar")';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$.array ? (@[*] == "bar")';
+    j @? '$.array ? (@[*] == "bar")';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$.array[*] ? (@ == "bar")';
+    j @? '$.array[*] ? (@ == "bar")';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$';
+    j @? '$';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$.public';
+    j @? '$.public';
 
 SELECT
     count(*)
 FROM
     testjsonb
 WHERE
-    j @ ? '$.bar';
+    j @? '$.bar';
 
 RESET enable_seqscan;
 
@@ -3599,26 +3600,26 @@ SELECT
 
 -- ts_headline for jsonb
 SELECT
-    ts_headline('{"a": "aaa bbb", "b": {"c": "ccc ddd fff", "c1": "ccc1 ddd1"}, "d": ["ggg hhh", "iii jjj"]}'::jsonb, tsquery ('bbb & ddd & hhh'));
+    ts_headline('{"a": "aaa bbb", "b": {"c": "ccc ddd fff", "c1": "ccc1 ddd1"}, "d": ["ggg hhh", "iii jjj"]}'::jsonb, tsquery('bbb & ddd & hhh'));
 
 SELECT
-    ts_headline('english', '{"a": "aaa bbb", "b": {"c": "ccc ddd fff"}, "d": ["ggg hhh", "iii jjj"]}'::jsonb, tsquery ('bbb & ddd & hhh'));
+    ts_headline('english', '{"a": "aaa bbb", "b": {"c": "ccc ddd fff"}, "d": ["ggg hhh", "iii jjj"]}'::jsonb, tsquery('bbb & ddd & hhh'));
 
 SELECT
-    ts_headline('{"a": "aaa bbb", "b": {"c": "ccc ddd fff", "c1": "ccc1 ddd1"}, "d": ["ggg hhh", "iii jjj"]}'::jsonb, tsquery ('bbb & ddd & hhh'), 'StartSel = <, StopSel = >');
+    ts_headline('{"a": "aaa bbb", "b": {"c": "ccc ddd fff", "c1": "ccc1 ddd1"}, "d": ["ggg hhh", "iii jjj"]}'::jsonb, tsquery('bbb & ddd & hhh'), 'StartSel = <, StopSel = >');
 
 SELECT
-    ts_headline('english', '{"a": "aaa bbb", "b": {"c": "ccc ddd fff", "c1": "ccc1 ddd1"}, "d": ["ggg hhh", "iii jjj"]}'::jsonb, tsquery ('bbb & ddd & hhh'), 'StartSel = <, StopSel = >');
+    ts_headline('english', '{"a": "aaa bbb", "b": {"c": "ccc ddd fff", "c1": "ccc1 ddd1"}, "d": ["ggg hhh", "iii jjj"]}'::jsonb, tsquery('bbb & ddd & hhh'), 'StartSel = <, StopSel = >');
 
 -- corner cases for ts_headline with jsonb
 SELECT
-    ts_headline('null'::jsonb, tsquery ('aaa & bbb'));
+    ts_headline('null'::jsonb, tsquery('aaa & bbb'));
 
 SELECT
-    ts_headline('{}'::jsonb, tsquery ('aaa & bbb'));
+    ts_headline('{}'::jsonb, tsquery('aaa & bbb'));
 
 SELECT
-    ts_headline('[]'::jsonb, tsquery ('aaa & bbb'));
+    ts_headline('[]'::jsonb, tsquery('aaa & bbb'));
 
 -- casts
 SELECT
