@@ -1163,7 +1163,11 @@ CREATE TABLE part_p2 PARTITION OF part DEFAULT PARTITION BY RANGE (a);
 CREATE TABLE part_p2_p1 PARTITION OF part_p2 DEFAULT;
 
 INSERT INTO part
-    VALUES (-1, -1), (1, 1), (2, NULL), (NULL, -2), (NULL, NULL);
+    VALUES (-1, -1),
+    (1, 1),
+    (2, NULL),
+    (NULL, -2),
+    (NULL, NULL);
 
 EXPLAIN (
     COSTS OFF
@@ -2075,7 +2079,8 @@ FROM
 
 -- and insert some values that we should find.
 INSERT INTO lprt_a
-    VALUES (1), (1);
+    VALUES (1),
+    (1);
 
 ANALYZE lprt_a;
 
@@ -2110,7 +2115,8 @@ SELECT
     explain_parallel_append ('select avg(ab.a) from ab inner join lprt_a a on ab.a = a.a + 0 where a.a in(0, 0, 1)');
 
 INSERT INTO lprt_a
-    VALUES (3), (3);
+    VALUES (3),
+    (3);
 
 SELECT
     explain_parallel_append ('select avg(ab.a) from ab inner join lprt_a a on ab.a = a.a where a.a in(1, 0, 3)');
@@ -2312,7 +2318,10 @@ TABLE ab;
 TRUNCATE ab;
 
 INSERT INTO ab
-    VALUES (1, 1), (1, 2), (1, 3), (2, 1);
+    VALUES (1, 1),
+    (1, 2),
+    (1, 3),
+    (2, 1);
 
 EXPLAIN (
     ANALYZE,
@@ -2344,7 +2353,8 @@ CREATE TABLE tbl1 (
 );
 
 INSERT INTO tbl1
-    VALUES (501), (505);
+    VALUES (501),
+    (505);
 
 -- Basic table
 CREATE TABLE tprt (
@@ -2383,7 +2393,13 @@ CREATE INDEX tprt5_idx ON tprt_5 (col1);
 CREATE INDEX tprt6_idx ON tprt_6 (col1);
 
 INSERT INTO tprt
-    VALUES (10), (20), (501), (502), (505), (1001), (4500);
+    VALUES (10),
+    (20),
+    (501),
+    (502),
+    (505),
+    (1001),
+    (4500);
 
 SET enable_hashjoin = OFF;
 
@@ -2435,7 +2451,9 @@ ORDER BY
 
 -- Multiple partitions
 INSERT INTO tbl1
-    VALUES (1001), (1010), (1011);
+    VALUES (1001),
+    (1010),
+    (1011);
 
 EXPLAIN (
     ANALYZE,
@@ -2780,7 +2798,8 @@ CREATE TABLE boolvalues (
 );
 
 INSERT INTO boolvalues
-    VALUES ('t'), ('f');
+    VALUES ('t'),
+    ('f');
 
 CREATE TABLE boolp (
     a bool
@@ -3022,7 +3041,9 @@ CREATE TABLE pph_arrpart2 PARTITION OF pph_arrpart
 FOR VALUES WITH (MODULUS 2, REMAINDER 1);
 
 INSERT INTO pph_arrpart
-    VALUES ('{1}'), ('{1, 2}'), ('{4, 5}');
+    VALUES ('{1}'),
+    ('{1, 2}'),
+    ('{4, 5}');
 
 SELECT
     tableoid::regclass,
