@@ -53,8 +53,14 @@ CREATE OR REPLACE FUNCTION f_leak (text)
     RETURNS bool
     COST 0.0000001
     LANGUAGE plpgsql
-    AS 'BEGIN RAISE NOTICE ''f_leak => %'', $1; RETURN true; END'
-;
+    AS '
+BEGIN
+    RAISE NOTICE ''f_leak => %'', $1;
+
+RETURN TRUE;
+
+END;
+';
 
 GRANT EXECUTE ON FUNCTION f_leak (text) TO public;
 
