@@ -5,7 +5,9 @@ CREATE TABLE tidscan (
 
 -- only insert a few rows, we don't want to spill onto a second table page
 INSERT INTO tidscan
-    VALUES (1), (2), (3);
+    VALUES (1),
+    (2),
+    (3);
 
 -- show ctids
 SELECT
@@ -42,14 +44,16 @@ SELECT
     *
 FROM
     tidscan
-WHERE '(0,1)' = ctid;
+WHERE
+    '(0,1)' = ctid;
 
 SELECT
     ctid,
     *
 FROM
     tidscan
-WHERE '(0,1)' = ctid;
+WHERE
+    '(0,1)' = ctid;
 
 -- OR'd clauses
 EXPLAIN (
