@@ -321,7 +321,8 @@ INSERT INTO upsert_test
     VALUES (1, 'Bar')
 ON CONFLICT (a)
     DO UPDATE SET
-        (b, a) = (
+        (b,
+            a) = (
             SELECT
                 b,
                 a
@@ -335,7 +336,8 @@ INSERT INTO upsert_test
     VALUES (1, 'Baz')
 ON CONFLICT (a)
     DO UPDATE SET
-        (b, a) = (
+        (b,
+            a) = (
             SELECT
                 b || ', Correlated',
                 a
@@ -351,7 +353,8 @@ INSERT INTO upsert_test
     VALUES (1, 'Bat')
 ON CONFLICT (a)
     DO UPDATE SET
-        (b, a) = (
+        (b,
+            a) = (
             SELECT
                 b || ', Excluded',
                 a
