@@ -9,7 +9,16 @@ CREATE TEMPORARY TABLE empsalary (
 );
 
 INSERT INTO empsalary
-    VALUES ('develop', 10, 5200, '2007-08-01'), ('sales', 1, 5000, '2006-10-01'), ('personnel', 5, 3500, '2007-12-10'), ('sales', 4, 4800, '2007-08-08'), ('personnel', 2, 3900, '2006-12-23'), ('develop', 7, 4200, '2008-01-01'), ('develop', 9, 4500, '2008-01-01'), ('sales', 3, 4800, '2007-08-01'), ('develop', 8, 6000, '2006-10-01'), ('develop', 11, 5200, '2007-08-15');
+    VALUES ('develop', 10, 5200, '2007-08-01'),
+    ('sales', 1, 5000, '2006-10-01'),
+    ('personnel', 5, 3500, '2007-12-10'),
+    ('sales', 4, 4800, '2007-08-08'),
+    ('personnel', 2, 3900, '2006-12-23'),
+    ('develop', 7, 4200, '2008-01-01'),
+    ('develop', 9, 4500, '2008-01-01'),
+    ('sales', 3, 4800, '2007-08-01'),
+    ('develop', 8, 6000, '2006-10-01'),
+    ('develop', 11, 5200, '2007-08-15');
 
 SELECT
     depname,
@@ -1128,7 +1137,15 @@ CREATE temp TABLE numerics (
 
 INSERT INTO numerics
     VALUES (0, '-infinity', '-infinity', '-1000'), -- numeric type lacks infinities
-    (1, -3, -3, -3), (2, -1, -1, -1), (3, 0, 0, 0), (4, 1.1, 1.1, 1.1), (5, 1.12, 1.12, 1.12), (6, 2, 2, 2), (7, 100, 100, 100), (8, 'infinity', 'infinity', '1000'), (9, 'NaN', 'NaN', 'NaN');
+    (1, -3, -3, -3),
+    (2, -1, -1, -1),
+    (3, 0, 0, 0),
+    (4, 1.1, 1.1, 1.1),
+    (5, 1.12, 1.12, 1.12),
+    (6, 2, 2, 2),
+    (7, 100, 100, 100),
+    (8, 'infinity', 'infinity', '1000'),
+    (9, 'NaN', 'NaN', 'NaN');
 
 SELECT
     id,
@@ -1241,7 +1258,16 @@ CREATE temp TABLE datetimes (
 );
 
 INSERT INTO datetimes
-    VALUES (1, '11:00', '11:00 BST', '1 year', '2000-10-19 10:23:54+01', '2000-10-19 10:23:54'), (2, '12:00', '12:00 BST', '2 years', '2001-10-19 10:23:54+01', '2001-10-19 10:23:54'), (3, '13:00', '13:00 BST', '3 years', '2001-10-19 10:23:54+01', '2001-10-19 10:23:54'), (4, '14:00', '14:00 BST', '4 years', '2002-10-19 10:23:54+01', '2002-10-19 10:23:54'), (5, '15:00', '15:00 BST', '5 years', '2003-10-19 10:23:54+01', '2003-10-19 10:23:54'), (6, '15:00', '15:00 BST', '5 years', '2004-10-19 10:23:54+01', '2004-10-19 10:23:54'), (7, '17:00', '17:00 BST', '7 years', '2005-10-19 10:23:54+01', '2005-10-19 10:23:54'), (8, '18:00', '18:00 BST', '8 years', '2006-10-19 10:23:54+01', '2006-10-19 10:23:54'), (9, '19:00', '19:00 BST', '9 years', '2007-10-19 10:23:54+01', '2007-10-19 10:23:54'), (10, '20:00', '20:00 BST', '10 years', '2008-10-19 10:23:54+01', '2008-10-19 10:23:54');
+    VALUES (1, '11:00', '11:00 BST', '1 year', '2000-10-19 10:23:54+01', '2000-10-19 10:23:54'),
+    (2, '12:00', '12:00 BST', '2 years', '2001-10-19 10:23:54+01', '2001-10-19 10:23:54'),
+    (3, '13:00', '13:00 BST', '3 years', '2001-10-19 10:23:54+01', '2001-10-19 10:23:54'),
+    (4, '14:00', '14:00 BST', '4 years', '2002-10-19 10:23:54+01', '2002-10-19 10:23:54'),
+    (5, '15:00', '15:00 BST', '5 years', '2003-10-19 10:23:54+01', '2003-10-19 10:23:54'),
+    (6, '15:00', '15:00 BST', '5 years', '2004-10-19 10:23:54+01', '2004-10-19 10:23:54'),
+    (7, '17:00', '17:00 BST', '7 years', '2005-10-19 10:23:54+01', '2005-10-19 10:23:54'),
+    (8, '18:00', '18:00 BST', '8 years', '2006-10-19 10:23:54+01', '2006-10-19 10:23:54'),
+    (9, '19:00', '19:00 BST', '9 years', '2007-10-19 10:23:54+01', '2007-10-19 10:23:54'),
+    (10, '20:00', '20:00 BST', '10 years', '2008-10-19 10:23:54+01', '2008-10-19 10:23:54');
 
 SELECT
     id,
@@ -1697,7 +1723,9 @@ CREATE temp TABLE t1 (
 );
 
 INSERT INTO t1
-    VALUES (1, 1), (1, 2), (2, 2);
+    VALUES (1, 1),
+    (1, 2),
+    (2, 2);
 
 SELECT
     f1,
