@@ -2181,11 +2181,12 @@ INSERT INTO withz
         WHERE
             withz.k != EXCLUDED.k
         RETURNING
-            *)
-        SELECT
             *
-        FROM
-            aa;
+)
+    SELECT
+        *
+    FROM
+        aa;
 
 -- New query/snapshot demonstrates side-effects of previous query.
 SELECT
@@ -2305,7 +2306,8 @@ INSERT INTO withz
         VALUES (2, 'Blue')
     ON CONFLICT (k)
         DO UPDATE SET
-            (k, v) = (
+            (k,
+                v) = (
                 SELECT
                     k,
                     v
@@ -2320,7 +2322,8 @@ INSERT INTO withz
         VALUES (2, 'Red')
     ON CONFLICT (k)
         DO UPDATE SET
-            (k, v) = (
+            (k,
+                v) = (
                 SELECT
                     k,
                     v
