@@ -1,7 +1,10 @@
 CREATE FUNCTION fn_opf12 (INT4, INT2)
     RETURNS BIGINT
-    AS 'SELECT NULL::BIGINT;'
-    LANGUAGE SQL;
+    AS '
+    SELECT
+        NULL::BIGINT;
+'
+LANGUAGE SQL;
 
 SELECT
     1::NUMERIC,
